
package t::Config;
@drivers    = qw(gnuplot xmgrace);
$xrt3d      = "";
$xrt2d      = "";
$xvfb      = "/usr/bin/Xvfb";

1;

    